@@ -1,7 +1,7 @@
 # Copyright (c) Naas Team.
 # Distributed under the terms of the GNU AGPL License.
+from .types import t_tz, t_size, error_busy, error_reject, copy_button
 from IPython.core.display import display, Javascript, HTML
-from .types import t_tz, error_busy, error_reject, copy_button
 from .runner.notifications import Notifications
 from .runner.callback import Callback
 from .dependency import Dependency
@@ -16,7 +16,7 @@ from .api import Api
 import requests
 import os
 
-__version__ = "1.1.2"
+__version__ = "1.3.15"
 __github_repo = "jupyter-naas/naas"
 __doc_url = "https://naas.gitbook.io/naas/"
 __canny_js = '<script>!function(w,d,i,s){function l(){if(!d.getElementById(i)){var f=d.getElementsByTagName(s)[0],e=d.createElement(s);e.type="text/javascript",e.async=!0,e.src="https://canny.io/sdk.js",f.parentNode.insertBefore(e,f)}}if("function"!=typeof w.Canny){var c=function(){c.q.push(arguments)};c.q=[],w.Canny=c,"complete"===d.readyState?l():w.attachEvent?w.attachEvent("onload",l):w.addEventListener("load",l,!1)}}(window,document,"canny-jssdk","script");</script>'  # noqa: E501
@@ -48,6 +48,11 @@ def get_last_version():
     return response.json()[0]["name"]
 
 
+def get_size():
+    response = requests.get(f"{n_env.api}/{t_size}")
+    return response.json()
+
+
 def changelog():
     data = __canny_js
     data += """<button class="lm-Widget p-Widget jupyter-widgets jupyter-button widget-button mod-primary" data-canny-changelog>
