@@ -10,6 +10,7 @@ from .controllers.jobs import JobsController
 from .controllers.logs import LogsController
 from sanic_openapi import swagger_blueprint
 from .controllers.env import EnvController
+from .controllers.size import SizeController
 from .notifications import Notifications
 from naas.onboarding import init_onborading
 from .proxy import escape_kubernet
@@ -43,7 +44,7 @@ from naas.types import (
 asyncio.set_event_loop_policy(None)
 nest_asyncio.apply()
 
-__version__ = "1.1.2"
+__version__ = "1.3.15"
 
 
 class Runner:
@@ -98,6 +99,10 @@ class Runner:
                 EnvController.as_view(),
                 "/env",
             )
+            self.__app.add_route(
+                SizeController.as_view(),
+                "/size",
+            )
             self.__app.add_route(LogsController.as_view(self.__logger), "/log")
             self.__app.add_route(
                 ManagerController.as_view(self.__path_lib_files),
