@@ -1,5 +1,4 @@
 from .types import t_scheduler, t_output, t_add, t_update, t_delete
-from .runner.env_var import n_env
 from .manager import Manager
 import pretty_cron
 import requests
@@ -69,12 +68,7 @@ class Scheduler:
                 if item["type"] == self.role and item["status"] != t_delete:
                     cron_string = pretty_cron.prettify_cron(item["value"])
                     kind = f"scheduler {cron_string}"
-                    path = (
-                        item["path"]
-                        .replace(n_env.path_naas_folder, "")
-                        .replace(n_env.server_root, "")
-                    )
-                    print(f"File ==> {path} is {kind}")
+                    print(f'File ==> {item["path"]} is {kind}')
 
     def __check_cron(self, text):
         res = False
